summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/oscar/liboscar/sendmessagetask.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:34 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:34 -0600
commit83677e35509b4dafac63b76995652bdf3b49f209 (patch)
tree591f1dc22278addb439726c42896376b17bb42bd /kopete/protocols/oscar/liboscar/sendmessagetask.cpp
parent808e453c56036211f57482ed847d54aca01bba68 (diff)
downloadtdenetwork-83677e35509b4dafac63b76995652bdf3b49f209.tar.gz
tdenetwork-83677e35509b4dafac63b76995652bdf3b49f209.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 808e453c56036211f57482ed847d54aca01bba68.
Diffstat (limited to 'kopete/protocols/oscar/liboscar/sendmessagetask.cpp')
-rw-r--r--kopete/protocols/oscar/liboscar/sendmessagetask.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kopete/protocols/oscar/liboscar/sendmessagetask.cpp b/kopete/protocols/oscar/liboscar/sendmessagetask.cpp
index 1b8cbfbc..596e6791 100644
--- a/kopete/protocols/oscar/liboscar/sendmessagetask.cpp
+++ b/kopete/protocols/oscar/liboscar/sendmessagetask.cpp
@@ -379,8 +379,8 @@ if ( !codec && ( contact->hasCap(CAP_UTF8) || !contact->encoding() ) )
utfMessage=new unsigned char[length];
for(unsigned int l=0; l<message.length(); l++)
{
- utfMessage[l*2]=message.unicode()[l].row();
- utfMessage[(l*2)+1]=message.unicode()[l].cell();
+ utfMessage[l*2]=message.tqunicode()[l].row();
+ utfMessage[(l*2)+1]=message.tqunicode()[l].cell();
}
charset=0x0002; // send UTF-16BE
}
@@ -393,7 +393,7 @@ if(!codec && charset != 0x0002 && contact->encoding() != 0)
charset=0x0003; //send as ISO-8859-1
}
-if(!codec && charset != 0x0002) // it's neither unicode nor did we find a codec so far!
+if(!codec && charset != 0x0002) // it's neither tqunicode nor did we find a codec so far!
{
kdDebug(14151) << k_funcinfo <<
"Couldn't find suitable encoding for outgoing message, " <<